Description Usage Arguments Details Examples
View source: R/aoe2_player_profile_all.r
This function gives you all available ranked player data. (The goal is it to have a function which creates a player object on which it would be easier to perfom regular summary funcitons)
1 | aoe2_player_profile_all(player_id, game = "aoe2de")
|
player_id |
Either profile_id or 64 bit steam id. Function takes either value and changes the api call accordingly |
game |
Default is aoe2de since the api is mostly used for that. |
More Information about aoe2.net api at https://aoe2.net/#api
1 2 3 4 | #Profile of GL. TheViper with profile_id
aoe2_player_profile(player_id=196240)
#Profile of GL. TheViper with steam_id
aoe2_player_profile(player_id=76561197984749679)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.